﻿using System;
using System.Runtime.InteropServices;
using System.ComponentModel;
using System.Windows.Forms;
using AddinExpress.MSO;
using Excel = Microsoft.Office.Interop.Excel;
using Microsoft.Win32;

namespace ExcelAddinSample2
{
    /// <summary>
    ///   Add-in Express Add-in Module
    /// </summary>
    [GuidAttribute("1BAF50D6-9533-49B6-BB7D-D3D5BA77247F"), ProgId("ExcelAddinSample2.AddinModule")]
    public partial class AddinModule : AddinExpress.MSO.ADXAddinModule
    {
        public AddinModule()
        {
            Application.EnableVisualStyles();
            InitializeComponent();
            // Please add any initialization code to the AddinInitialize event handler
        }
 
        #region Add-in Express automatic code
 
        // Required by Add-in Express - do not modify
        // the methods within this region
 
        public override System.ComponentModel.IContainer GetContainer()
        {
            if (components == null)
                components = new System.ComponentModel.Container();
            return components;
        }
 
        [ComRegisterFunctionAttribute]
        public static void AddinRegister(Type t)
        {
            AddinExpress.MSO.ADXAddinModule.ADXRegister(t);
        }
 
        [ComUnregisterFunctionAttribute]
        public static void AddinUnregister(Type t)
        {
            AddinExpress.MSO.ADXAddinModule.ADXUnregister(t);
        }
 
        public override void UninstallControls()
        {
            base.UninstallControls();
        }

        #endregion

        public static new AddinModule CurrentInstance 
        {
            get
            {
                return AddinExpress.MSO.ADXAddinModule.CurrentInstance as AddinModule;
            }
        }

        public Excel._Application ExcelApp
        {
            get
            {
                return (HostApplication as Excel._Application);
            }
        }

        private bool _module1Enabled = true;
        private bool _module2Enabled = true;
        private bool _xll1Enabled = true;
        private bool _xll2Enabled = true;

        private void AddinModule_OnRibbonBeforeCreate(object sender, string ribbonId)
        {
            LoadSettings();

            ApplySettings();
        }

        private void AddinModule_AddinInitialize(object sender, EventArgs e)
        {
            LoadSettings();

            ApplySettings();
        }

        private void adxRibbonCheckBox1_OnClick(object sender, IRibbonControl control, bool pressed)
        {
            this._module1Enabled = pressed;
            SaveSettings();
        }

        private void adxRibbonCheckBox2_OnClick(object sender, IRibbonControl control, bool pressed)
        {
            this._module2Enabled = pressed;
            SaveSettings();
        }

        private void adxRibbonCheckBox3_OnClick(object sender, IRibbonControl control, bool pressed)
        {
            this._xll1Enabled = pressed;
            SaveSettings();
        }

        private void adxRibbonCheckBox4_OnClick(object sender, IRibbonControl control, bool pressed)
        {
            this._xll2Enabled = pressed;
            SaveSettings();
        }

        private void ApplySettings()
        {
            if (!this._module1Enabled)
            {
                adxRibbonCheckBox1.Pressed = false;
                this.Modules.Remove(this.adxAddinAdditionalModuleItem1);
            }
            if (!this._module2Enabled)
            {
                adxRibbonCheckBox2.Pressed = false;
                this.Modules.Remove(this.adxAddinAdditionalModuleItem2);
            }

            adxRibbonCheckBox3.Pressed = this._xll1Enabled;
            adxRibbonCheckBox4.Pressed = this._xll2Enabled;
        }

        private void LoadSettings()
        {
            RegistryKey key = Registry.CurrentUser.OpenSubKey(this.RegistryKey + "\\Settings", false);
            if (key != null)
                try
                {
                    this._module1Enabled = Convert.ToBoolean(key.GetValue("Module1", true));
                    this._module2Enabled = Convert.ToBoolean(key.GetValue("Module2", true));

                    this._xll1Enabled = Convert.ToBoolean(key.GetValue("XLL1", true));
                    this._xll2Enabled = Convert.ToBoolean(key.GetValue("XLL2", true));
                }
                finally { key.Close(); }
        }

        private void SaveSettings()
        {
            RegistryKey key = Registry.CurrentUser.OpenSubKey(this.RegistryKey + "\\Settings", true);
            if (key == null)
                key = Registry.CurrentUser.CreateSubKey(this.RegistryKey + "\\Settings");
            if (key != null)
                try
                {
                    key.SetValue("Module1", this._module1Enabled);
                    key.SetValue("Module2", this._module2Enabled);

                    key.SetValue("XLL1", this._xll1Enabled);
                    key.SetValue("XLL2", this._xll2Enabled);
                }
                finally { key.Close(); }
        }
    }
}

